@@ -7,8 +7,7 @@ from trytond.model import fields
 __all__ = ['TaxRuleLineTemplate', 'TaxRuleLine', 'InvoiceLine']
 
 
-class TaxRuleLineTemplate:
-    __metaclass__ = PoolMeta
+class TaxRuleLineTemplate(metaclass=PoolMeta):
     __name__ = 'account.tax.rule.line.template'
     from_country = fields.Many2One('country.country', 'From Country',
         ondelete='RESTRICT')
@@ -27,8 +26,7 @@ class TaxRuleLineTemplate:
         return value
 
 
-class TaxRuleLine:
-    __metaclass__ = PoolMeta
+class TaxRuleLine(metaclass=PoolMeta):
     __name__ = 'account.tax.rule.line'
     from_country = fields.Many2One('country.country', 'From Country',
         ondelete='RESTRICT')
@@ -36,10 +34,10 @@ class TaxRuleLine:
         ondelete='RESTRICT')
 
 
-class InvoiceLine:
-    __metaclass__ = PoolMeta
+class InvoiceLine(metaclass=PoolMeta):
     __name__ = 'account.invoice.line'
 
+    @fields.depends('origin')
     def _get_tax_rule_pattern(self):
         pool = Pool()
         SaleLine = pool.get('sale.line')
@@ -60,11 +58,3 @@ class InvoiceLine:
         pattern['from_country'] = from_country.id if from_country else None
         pattern['to_country'] = to_country.id if to_country else None
         return pattern
-
-    @fields.depends('origin')
-    def on_change_product(self):
-        super(InvoiceLine, self).on_change_product()
-
-    @fields.depends('origin')
-    def on_change_account(self):
-        super(InvoiceLine, self).on_change_account()
