@@ -8,8 +8,7 @@ from trytond.pyson import Eval
 __all__ = ['Purchase', 'PurchaseLine']
 
 
-class Purchase:
-    __metaclass__ = PoolMeta
+class Purchase(metaclass=PoolMeta):
     __name__ = 'purchase.purchase'
 
     @classmethod
@@ -21,10 +20,11 @@ class Purchase:
             field.depends.extend(['invoice_address'])
 
 
-class PurchaseLine:
-    __metaclass__ = PoolMeta
+class PurchaseLine(metaclass=PoolMeta):
     __name__ = 'purchase.line'
 
+    @fields.depends('purchase', '_parent_purchase.warehouse',
+        '_parent_purchase.invoice_address')
     def _get_tax_rule_pattern(self):
         pattern = super(PurchaseLine, self)._get_tax_rule_pattern()
 
@@ -39,8 +39,3 @@ class PurchaseLine:
         pattern['from_country'] = from_country.id if from_country else None
         pattern['to_country'] = to_country.id if to_country else None
         return pattern
-
-    @fields.depends('_parent_purchase.warehouse',
-        '_parent_purchase.invoice_address')
-    def on_change_product(self):
-        super(PurchaseLine, self).on_change_product()
